@@ -71,7 +71,8 @@ class HttpClientFactory:
             json_data: Any = None,
             data: Any = None,
             headers: Dict[str, str] = None,
-            is_end: bool = True
+            is_end: bool = True,
+            has_cookie: bool = False
     ) -> Any:
 
         method = method.lower().strip()
@@ -121,6 +122,8 @@ class HttpClientFactory:
                             content = await resp.content.readany()
                             content = content.decode('utf-8')
                             json_data = dict(code=resp.status, message=get_html_title(html=content), data=content)
+                        if has_cookie is True:
+                            json_data["cookies"] = resp.headers.get("Set-Cookie")
                         if is_end is True:
                             await self.session.close()
                         return json_data
@@ -131,3 +134,9 @@ class HttpClientFactory:
                 if attempt == attempts:
                     raise HttpClientError(f"Request failed after {attempts} attempts: {e}")
                 await asyncio.sleep(1 * attempt)  # 递增式重试间隔
+        if is_end is True and self.session:
+            await self.session.close()
+
+    async def close(self):
+        if self.session:
+            await self.session.close()
